Crate sims

Crate sims 

Simplistic string search

This crate implements simplistic searches of byte slices, that may be accelerated via SIMD operations.

Currently, only a generic and an SSE4.2-optimized versions are available. Selection is done at runtime via feature detection.

Functions

find_first_not_of
Find the index of the first byte in a slice that is not equal to an element of another slice.
find_first_of
Find the index of the first byte in a slice that is equal to an element of another slice.